##########
Quick start
##########

Installation
============
trackc requires Python version >= 3.8 to run.

**PyPI**

Install trackc by running:

.. code-block:: bash

    pip install trackc

update trackc by running:

.. code-block:: bash

    pip install --upgrade trackc

run this pip command to specify the version and installation source:

.. code-block:: bash

    pip install -i https://pypi.org/simple trackc==0.1.2

**Conda**

Install trackc via Conda as::

    conda install -c conda-forge trackc

**Development version**

To install Squidpy from GitHub, run::

    pip install git+https://github.com/seqyuan/trackc@main


Quick start
===========
This section contains various quick tutorials showcasing omics data visualization with :mod:`trackc`.

Analysis of Hi-C using :mod:`trackc`
-------------------------------------------------
This section contains tutorials showcasing core trackc functionalities by applying them
to a diverse set of different Hi-C datasets.

.. code-block:: python

    'example mapc code'
